pitchtools.Accidental
=====================

.. abjad-lineage:: abjad.tools.pitchtools.Accidental.Accidental

.. autoclass:: abjad.tools.pitchtools.Accidental.Accidental

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.Accidental.Accidental.abbreviation
      ~abjad.tools.pitchtools.Accidental.Accidental.is_abbreviation
      ~abjad.tools.pitchtools.Accidental.Accidental.is_adjusted
      ~abjad.tools.pitchtools.Accidental.Accidental.is_symbolic_string
      ~abjad.tools.pitchtools.Accidental.Accidental.name
      ~abjad.tools.pitchtools.Accidental.Accidental.semitones
      ~abjad.tools.pitchtools.Accidental.Accidental.symbolic_string
      ~abjad.tools.pitchtools.Accidental.Accidental.__add__
      ~abjad.tools.pitchtools.Accidental.Accidental.__eq__
      ~abjad.tools.pitchtools.Accidental.Accidental.__format__
      ~abjad.tools.pitchtools.Accidental.Accidental.__ge__
      ~abjad.tools.pitchtools.Accidental.Accidental.__gt__
      ~abjad.tools.pitchtools.Accidental.Accidental.__hash__
      ~abjad.tools.pitchtools.Accidental.Accidental.__le__
      ~abjad.tools.pitchtools.Accidental.Accidental.__lt__
      ~abjad.tools.pitchtools.Accidental.Accidental.__ne__
      ~abjad.tools.pitchtools.Accidental.Accidental.__neg__
      ~abjad.tools.pitchtools.Accidental.Accidental.__nonzero__
      ~abjad.tools.pitchtools.Accidental.Accidental.__repr__
      ~abjad.tools.pitchtools.Accidental.Accidental.__str__
      ~abjad.tools.pitchtools.Accidental.Accidental.__sub__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.abbreviation
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.is_adjusted
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.name
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.semitones
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.Accidental.Accidental.symbolic_string
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.is_abbreviation
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.is_symbolic_string
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__neg__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__nonzero__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.Accidental.Accidental.__sub__
   :noindex:
